@@ -1,9 +1,12 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/Queue/PreferencesDB.pm - some user functions
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
+# --
+# $Id: PreferencesDB.pm,v 1.4 2008/05/08 09:36:21 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::System::Queue::PreferencesDB;
@@ -11,6 +14,9 @@ package Kernel::System::Queue::PreferencesDB;
 use strict;
 use warnings;
 
+use vars qw(@ISA $VERSION);
+$VERSION = qw($Revision: 1.4 $) [1];
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -19,7 +25,7 @@ sub new {
     bless( $Self, $Type );
 
     # check needed objects
-    for (qw(DBObject ConfigObject LogObject EncodeObject MainObject CacheInternalObject)) {
+    for (qw(DBObject ConfigObject LogObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
 
@@ -29,13 +35,6 @@ sub new {
     $Self->{PreferencesTableValue}   = 'preferences_value';
     $Self->{PreferencesTableQueueID} = 'queue_id';
 
-    # create cache prefix
-    $Self->{CachePrefix} = 'QueuePreferencesDB'
-        . $Self->{PreferencesTable}
-        . $Self->{PreferencesTableKey}
-        . $Self->{PreferencesTableValue}
-        . $Self->{PreferencesTableQueueID};
-
     return $Self;
 }
 
@@ -44,11 +43,8 @@ sub QueuePreferencesSet {
 
     # check needed stuff
     for (qw(QueueID Key Value)) {
-        if ( !defined $Param{$_} ) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+        if ( !defined( $Param{$_} ) ) {
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
@@ -61,19 +57,12 @@ sub QueuePreferencesSet {
     );
 
     # insert new data
-    return if !$Self->{DBObject}->Do(
+    return $Self->{DBObject}->Do(
         SQL => "INSERT INTO $Self->{PreferencesTable} ($Self->{PreferencesTableQueueID}, "
             . " $Self->{PreferencesTableKey}, $Self->{PreferencesTableValue}) "
             . " VALUES (?, ?, ?)",
         Bind => [ \$Param{QueueID}, \$Param{Key}, \$Param{Value} ],
     );
-
-    # delete cache
-    $Self->{CacheInternalObject}->Delete(
-        Key => $Self->{CachePrefix} . $Param{QueueID},
-    );
-
-    return 1;
 }
 
 sub QueuePreferencesGet {
@@ -82,22 +71,15 @@ sub QueuePreferencesGet {
     # check needed stuff
     for (qw(QueueID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
 
     # check if queue preferences are available
-    return if !$Self->{ConfigObject}->Get('QueuePreferences');
-
-    # read cache
-    my $Cache = $Self->{CacheInternalObject}->Get(
-        Key => $Self->{CachePrefix} . $Param{QueueID},
-    );
-    return %{$Cache} if $Cache;
+    if ( !$Self->{ConfigObject}->Get('QueuePreferences') ) {
+        return;
+    }
 
     # get preferences
     return if !$Self->{DBObject}->Prepare(
@@ -105,18 +87,12 @@ sub QueuePreferencesGet {
             . " FROM $Self->{PreferencesTable} WHERE $Self->{PreferencesTableQueueID} = ?",
         Bind => [ \$Param{QueueID} ],
     );
-
     my %Data;
     while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $Data{ $Row[0] } = $Row[1];
     }
 
-    # set cache
-    $Self->{CacheInternalObject}->Set(
-        Key   => $Self->{CachePrefix} . $Param{QueueID},
-        Value => \%Data,
-    );
-
+    # return data
     return %Data;
 }
 
