@@ -1,9 +1,13 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/System/Ticket/Permission/ResponsibleCheck.pm - the sub
+# module of the global ticket handle
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
+# --
+# $Id: ResponsibleCheck.pm,v 1.6 2008/04/25 09:04:24 tr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::System::Ticket::Permission::ResponsibleCheck;
@@ -11,6 +15,9 @@ package Kernel::System::Ticket::Permission::ResponsibleCheck;
 use strict;
 use warnings;
 
+use vars qw(@ISA $VERSION);
+$VERSION = qw($Revision: 1.6 $) [1];
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -32,27 +39,18 @@ sub Run {
     # check needed stuff
     for (qw(TicketID UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
 
-    # return if no responible feature is active
-    return if !$Self->{ConfigObject}->Get('Ticket::Responsible');
-
     # get ticket data
-    my %Ticket = $Self->{TicketObject}->TicketGet(
-        TicketID      => $Param{TicketID},
-        DynamicFields => 0,
-    );
+    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
 
-    # check ticket owner, return access if current user is ticket owner
-    return 1 if $Ticket{ResponsibleID} eq $Param{UserID};
-
-    # return no access
+    # check ticket owner with requested owner
+    if ( $Ticket{ResponsibleID} eq $Param{UserID} ) {
+        return 1;
+    }
     return;
 }
 
